/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#include <iostream>

// QT includes
#include <qdir.h>
#include <qfileinfo.h>
#include <qpixmap.h>

// KDE includes
#include <kfiledetailview.h>
#include <kglobal.h>

// Our includes
#include "filethumbnailview.h"

#include "filewidget.moc"



FileWidget::FileWidget(QWidget* parent,Mode mode) :
	QWidgetStack(parent)
{
// File detail widget
	mFileDetailView=new KFileDetailView(this,"filedetailview");
	addWidget(mFileDetailView,0);

	connect(mFileDetailView,SIGNAL(clicked(QListViewItem*)),this,SLOT(detailChanged(QListViewItem*)) );
	connect(mFileDetailView,SIGNAL(returnPressed(QListViewItem*)),this,SLOT(detailChanged(QListViewItem*)) );

// Thumbnail widget
	mFileThumbnailView=new FileThumbnailView(this);
	addWidget(mFileThumbnailView,1);
	
	connect(mFileThumbnailView,SIGNAL(clicked(QIconViewItem*)),this,SLOT(thumbnailChanged(QIconViewItem*)) );
	connect(mFileThumbnailView,SIGNAL(returnPressed(QIconViewItem*)),this,SLOT(thumbnailChanged(QIconViewItem*)) );

	setMode(mode);
}


FileWidget::~FileWidget() {
}


KFileView* FileWidget::currentFileView() const {
	if (mMode==FileList) {
		return mFileDetailView;
	} else {
		return mFileThumbnailView;
	}
}


void FileWidget::readConfig(KConfig* config,QString group) {
	mFileThumbnailView->readConfig(config,group);
}


void FileWidget::writeConfig(KConfig* config,QString group) const {
	mFileThumbnailView->writeConfig(config,group);
}


void FileWidget::select(QString filename) {
	KFileViewItem* item;
	currentFileView()->setCurrentItem(filename);
	item=currentFileView()->selectedItems()->getFirst();
	if (!item) {
		cout << "No '" << filename << "' found\n";
		return;
	}
	currentFileView()->ensureItemVisible(item);
	emit filenameChanged(filename);
}


void FileWidget::selectFirst() {
	KFileViewItemListIterator it(* (currentFileView()->items()) );
	KFileViewItem* item=it.toFirst();
	if (!item) return;
	currentFileView()->setSelected(item,true);
	currentFileView()->ensureItemVisible(item);
	emit filenameChanged(item->name());
}


void FileWidget::selectLast() {
	KFileViewItemListIterator it(* (currentFileView()->items()) );
	KFileViewItem* item=it.toLast();
	if (!item) return;
	currentFileView()->setSelected(item,true);
	currentFileView()->ensureItemVisible(item);
	emit filenameChanged(item->name());
}


void FileWidget::selectPrevious() {
	KFileViewItemListIterator it(* (currentFileView()->items()) );
	KFileViewItem* currentItem=currentFileView()->selectedItems()->getFirst();
	if (!currentItem) {
		return;
	}

	for(it.toLast();!it.atFirst();--it) {
		if ( (*it)==currentItem) {
			--it;
			currentFileView()->setSelected(*it,true);
			currentFileView()->ensureItemVisible(*it);
			emit filenameChanged( (*it)->name());
			return;
		}
	}
}


void FileWidget::selectNext() {
	KFileViewItemListIterator it(* (currentFileView()->items()) );
	KFileViewItem* currentItem=currentFileView()->selectedItems()->getFirst();
	if (!currentItem) {
		return;
	}

	for(;!it.atLast();++it) {
		if ( (*it)==currentItem) {
			++it;
			currentFileView()->setSelected(*it,true);
			currentFileView()->ensureItemVisible(*it);
			emit filenameChanged( (*it)->name());
			return;
		}
	}
}


void FileWidget::removeItem(KFileItem* item) {
	currentFileView()->removeItem((KFileViewItem*)item);
}


void FileWidget::newItems(const KFileItemList& items) {
	currentFileView()->addItemList(items);
}


void FileWidget::clear() {
	currentFileView()->clear();
}

	
	
void FileWidget::detailChanged(QListViewItem* item) {
	if (item) {
		emit filenameChanged(item->text(0));
	} else {
		emit filenameChanged("");
	}
}


void FileWidget::thumbnailChanged(QIconViewItem* item) {
	if (item) {
		emit filenameChanged(item->text());
	} else {
		emit filenameChanged("");
	}
}


void FileWidget::setMode(FileWidget::Mode mode) {
	if (mode==mMode) {
		return;
	}
	mMode=mode;
	
	if (mMode==FileList) {
		raiseWidget(mFileDetailView);
	} else {
		raiseWidget(mFileThumbnailView);
	}
}
